@@ -1,4 +1,5 @@
-# coding: utf-8
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 
 from trojanvision.datasets.imageset import ImageSet
 from trojanvision.models.imagemodel import ImageModel
@@ -89,7 +90,7 @@ class BadNet(Attack):
             mark_alpha = self.mark.mark_alpha
         if target_class is None:
             target_class = self.target_class
-        mark_filename = os.path.split(self.mark.mark_path)
+        mark_filename = os.path.split(self.mark.mark_path)[-1]
         mark_name, mark_ext = os.path.splitext(mark_filename)
         _file = '{mark}_tar{target:d}_alpha{mark_alpha:.2f}_mark({mark_height:d},{mark_width:d})'.format(
             mark=mark_name, target=target_class, mark_alpha=mark_alpha,
