@@ -1,4 +1,5 @@
-# coding: utf-8
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 
 from .badnet import BadNet
 from trojanvision.environ import env
@@ -38,7 +39,7 @@ class BypassEmbed(BadNet):
         poison_loader, discrim_loader = self.sample_data()  # with poisoned images
         print('Joint Training')
         super().attack(epoch=10, lr_scheduler=lr_scheduler, **kwargs)
-        if lr_scheduler is not None:
+        if isinstance(lr_scheduler, optim.lr_scheduler._LRScheduler):
             lr_scheduler.step(0)
         self.joint_train(epoch=epoch, poison_loader=poison_loader, discrim_loader=discrim_loader,
                          save=save, lr_scheduler=lr_scheduler, **kwargs)
