@@ -1,4 +1,5 @@
-# coding: utf-8
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 
 from ..backdoor_defense import BackdoorDefense
 from trojanzoo.utils import to_list
@@ -72,7 +73,7 @@ class FinePruning(BackdoorDefense):
         for i in range(min(10, length)):
             print('Iter: ', output_iter(i + 1, 10))
             self.prune_step(mask, prune_num=1)
-            _, target_acc, clean_acc = self.attack.validate_func()
+            _, clean_acc = self.attack.validate_func()
             if self.attack.clean_acc - clean_acc > 20:
                 break
         file_path = self.folder_path + self.get_filename() + '.pth'
