@@ -1,9 +1,10 @@
-# coding: utf-8
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 
 from trojanzoo.defenses import Defense
 from trojanvision.datasets import ImageSet
 from trojanvision.models import ImageModel
-from trojanvision.attacks import BadNet
+from trojanvision.attacks.backdoor import BadNet
 
 import argparse
 
