@@ -1,4 +1,5 @@
-# coding: utf-8
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 
 from trojanzoo.utils.output import prints, ansi
 from trojanzoo.utils.param import Module, Param
@@ -164,8 +165,8 @@ class Config:
                 prints('-' * 20, indent=indent + 10)
             prints('-' * 30, indent=indent)
 
-    def __str__(self):
-        return self.config_dict.__str__
+    def __str__(self) -> str:
+        return str(self.config_dict)
 
     def __repr__(self):
         return repr(self.config_dict)
