@@ -1,4 +1,5 @@
-# coding: utf-8
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 
 
 from trojanzoo.datasets import Dataset
@@ -9,12 +10,14 @@ from trojanzoo.utils.output import ansi, prints
 
 from torch.optim.optimizer import Optimizer
 from torch.optim.lr_scheduler import _LRScheduler
+from torch.utils.tensorboard import SummaryWriter
 import argparse
 
 
 class Trainer:
     name = 'trainer'
-    param_list: list[str] = ['optim_args', 'train_args', 'optimizer', 'lr_scheduler']
+    param_list: list[str] = ['optim_args', 'train_args', 'writer_args',
+                             'optimizer', 'lr_scheduler', 'writer']
 
     @staticmethod
     def add_argument(group: argparse._ArgumentGroup) -> argparse._ArgumentGroup:
@@ -44,14 +47,23 @@ class Trainer:
                            help='validate interval during training epochs, defaults to 10.')
         group.add_argument('--save', dest='save', action='store_true',
                            help='save training results.')
+        group.add_argument('--tensorboard', dest='tensorboard', action='store_true',
+                           help='save training logging for tensorboard.')
+        group.add_argument('--log_dir', dest='log_dir',
+                           help='save training logging for tensorboard.')
+        group.add_argument('--flush_secs', dest='flush_secs', type=int,
+                           help='How often, in seconds, to flush the pending events and summaries to disk.')
         return group
 
-    def __init__(self, optim_args: dict = {}, train_args: dict = {},
-                 optimizer: Optimizer = None, lr_scheduler: _LRScheduler = None):
+    def __init__(self, optim_args: dict = {}, train_args: dict = {}, writer_args: dict = {},
+                 optimizer: Optimizer = None, lr_scheduler: _LRScheduler = None,
+                 writer: SummaryWriter = None):
         self.optim_args = {} | optim_args   # to avoid BadAppend issues
         self.train_args = {} | train_args
-        self.optimizer: Optimizer = optimizer
-        self.lr_scheduler: _LRScheduler = lr_scheduler
+        self.writer_args = {} | writer_args
+        self.optimizer = optimizer
+        self.lr_scheduler = lr_scheduler
+        self.writer = writer
 
     def __getitem__(self, key: str):
         if key in self.train_args.keys():
@@ -67,6 +79,7 @@ class Trainer:
         keys: list[str] = self.param_list.copy()
         keys.remove('optim_args')
         keys.remove('train_args')
+        keys.remove('writer_args')
         keys.extend(list(self.train_args.keys()))
         return keys
 
@@ -86,22 +99,29 @@ def add_argument(parser: argparse.ArgumentParser) -> argparse._ArgumentGroup:
 
 
 def create(dataset_name: str = None, dataset: Dataset = None, model: Model = None,
-           config: Config = config, **kwargs) -> tuple[Optimizer, _LRScheduler, dict]:
+           tensorboard: bool = None, config: Config = config, **kwargs) -> tuple[Optimizer, _LRScheduler, dict]:
     assert isinstance(model, Model)
     dataset_name = get_name(name=dataset_name, module=dataset, arg_list=['-d', '--dataset'])
     result = config.get_config(dataset_name=dataset_name)['trainer']._update(kwargs)
 
     optim_keys = model.define_optimizer.__code__.co_varnames
     train_keys = model._train.__code__.co_varnames
+    writer_keys = SummaryWriter.__init__.__code__.co_varnames   # log_dir, flush_secs, ...
     optim_args = {}
     train_args = {}
+    writer_args = {}
     for key, value in result.items():
         if key in optim_keys:
             _dict = optim_args
         elif key in train_keys:
             _dict = train_args
+        elif key in writer_keys:
+            _dict = writer_args
         else:
             continue
         _dict[key] = value
     optimizer, lr_scheduler = model.define_optimizer(**optim_args)
-    return Trainer(optim_args=optim_args, train_args=train_args, optimizer=optimizer, lr_scheduler=lr_scheduler)
+    writer = SummaryWriter(**writer_args) if tensorboard else None
+    return Trainer(optim_args=optim_args, train_args=train_args,
+                   optimizer=optimizer, lr_scheduler=lr_scheduler,
+                   writer=writer)
